What it does?
===============
Web Scraping Using Python to Download and Apply Random Cat Images as Wallpaper According to Your Operating System

Supported platforms
===============
Presently, it provides support the following platforms mentioned below:

1. Windows
2. Mac
3. Linux with desktop environment: Gnome, Xfce, Mate, Kde plasma

Installation
===============

It's available on pypi as https://pypi.org/project/catwallpaper/


``pip install catwallpaper``
